import { Component, OnInit, ViewChild } from '@angular/core';
import { KompetenzService } from '../services/kompetenz.service';
import { Observable } from 'rxjs';
import { MatSliderModule } from '@angular/material/slider';
import { LiveAnnouncer } from '@angular/cdk/a11y';
import { MatTableDataSource } from '@angular/material/table';
import { MatSort, Sort } from '@angular/material/sort';
import { MatPaginator } from '@angular/material/paginator';
import { Kompetenz } from '../kompetenz';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { FormBuilder, UntypedFormBuilder, Validators } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';

@Component({
  selector: 'app-kompetenz',
  templateUrl: './kompetenz.component.html',
  styleUrls: ['./kompetenz.component.css']
})
export class KompetenzComponent implements OnInit {

  public kompetenzen: any;
  public selection: any;
  public dataSource: any;
  public editForm: any;
  public aktKompetenzId: any;
  public aktkompetenz?: Kompetenz;
  headers: HttpHeaders = new HttpHeaders()
                  .set('Accept', 'application/json');
                  

  displayedColumns: any = ["competenceid", "competence", "competencedescription"];

  constructor(private Kompetenz: KompetenzService,
              private _liveAnnouncer: LiveAnnouncer,
              private formbuilder: FormBuilder,
              private router: Router,
              private kompetenzservice: KompetenzService,
              private activatedRoute: ActivatedRoute,
              private http: HttpClient,) 
    { 
      this.editForm = this.formbuilder.group({
        competenceid: [],
        competence: ['', Validators.required],
        competencedescription: ['', Validators.required ],
        dauer: ['']
      })
  }

  ngOnInit(): void {

    this.Kompetenz.getKompetenzen().subscribe (
      (
        result: any) => {
        this.kompetenzen = result;
        this.dataSource = new MatTableDataSource(this.kompetenzen);
        this.dataSource.paginator = this.paginator;
        this.dataSource.sort = this.sort;
      })
  }
  @ViewChild('paginator') paginator: MatPaginator;
  @ViewChild(MatSort) sort: MatSort;

  ngAfterViewInit() {
    if(this.dataSource != undefined) {
      this.dataSource.paginator = this.paginator;
      this.dataSource.sort = this.sort;
      console.log(this.dataSource);
    }
    else
      console.log("DataSource undefined in AfterViewInit");

  }

  applyFilter(event: Event) {
    const filterValue = (event.target as HTMLInputElement).value;
    this.dataSource.filter = filterValue.trim().toLowerCase();
    console.log("Filter: " + this.dataSource.filter);
  }

  /** Announce the change in sort state for assistive technology. */
  announceSortChange(sortState: Sort) {
    // This example uses English messages. If your application supports
    // multiple language, you would internationalize these strings.
    // Furthermore, you can customize the message to add additional
    // details about the values being sorted.
    if (sortState.direction) {
      this._liveAnnouncer.announce(`Sorted ${sortState.direction}ending`);
    } else {
      this._liveAnnouncer.announce('Sorting cleared');
    }
  }
  
  onclick(aktuell: Kompetenz) {
    this.aktKompetenzId = aktuell.competenceid;
    console.log("ausgewählt: " + aktuell.competenceid)
    if (this.aktKompetenzId > 0) {
      this.kompetenzservice.getSingleKompetenz(this.aktKompetenzId).subscribe((
        (data: any) => {
       //   console.log(data);
          this.editForm.patchValue(data);
        }
      ))
    }
  }

  onEdit(): void {

  }
  onCancel(): void {
    this.editForm.reset();
  }
}

