import { Component, OnInit, ViewChild } from '@angular/core';
import { LehrlingService } from '../services/lehrling.service';
import { Observable } from 'rxjs';
import { Lehrling } from '../lehrling';
import { MatTableDataSource } from '@angular/material/table';
import { SelectionModel } from '@angular/cdk/collections';
import { Router } from '@angular/router';
import { UntypedFormBuilder, Validators } from '@angular/forms';
import { LiveAnnouncer } from '@angular/cdk/a11y';
import { MatSort, Sort } from '@angular/material/sort';
import { MatPaginator } from '@angular/material/paginator';

@Component({
  selector: 'app-list-lehrlinge',
  templateUrl: './list-lehrlinge.component.html',
  styleUrls: ['./list-lehrlinge.component.css']
})
export class ListLehrlingeComponent implements OnInit {

  public dsLehrlinge?: MatTableDataSource<Lehrling>;
  selection = new SelectionModel<Lehrling>(true, []);
  public lehrlinge: any;
  public displayedColumns: any;
  public editForm: any;
  public aktlehrling: any;

  constructor(private Lehrlinge: LehrlingService,
              private router: Router,
              private formbuilder: UntypedFormBuilder,
              private _liveAnnouncer: LiveAnnouncer,) 
              { 
                this.editForm = this.formbuilder.group({
                  apprenticeid: [],
                  firstname: ['', Validators.required],
                  lastname: ['', Validators.required],
                  groupid: [''],
                  sex: [''],
                  date_of_birth: [''],
                  date_joined: [''],
                  date_leave: ['']
                })
              }

  ngOnInit(): void {
    this.displayedColumns = ["apprenticeid", "firstname", "lastname", "groupname"];
    this.Lehrlinge.getLehrlinge().subscribe(
      (
        data: any) => {
        console.log(data);
        this.lehrlinge = data.apprentice;
        this.dsLehrlinge = this.lehrlinge;
    })
  }

  @ViewChild('paginator') paginator: MatPaginator;
  @ViewChild(MatSort) sort: MatSort;

  ngAfterViewInit() {
    if(this.dsLehrlinge != undefined) {
      this.dsLehrlinge.paginator = this.paginator;
      this.dsLehrlinge.sort = this.sort;
    //  console.log(this.dsLehrlinge);
    }
    else
      console.log("DataSource undefined in AfterViewInit");
  }
  
  onclick(aktlehrling: any) {
    this.aktlehrling = aktlehrling;
    console.log("ausgewählt: " + aktlehrling.lastname)
  }
    /** Selects all rows if they are not all selected; otherwise clear selection. */
    masterToggle() {
      this.isAllSelected() ?
          this.selection.clear() :
          this.dsLehrlinge.data.forEach(row => this.selection.select(row));
    }

      /** Whether the number of selected elements matches the total number of rows. */
  isAllSelected() {
    console.log(this.selection);
    const numSelected = this.selection.selected.length;
    const numRows = this.dsLehrlinge.data.length;
    return numSelected === numRows;
  }
  applyFilter(event: Event) {
    const filterValue = (event.target as HTMLInputElement).value;
    this.dsLehrlinge.filter = filterValue.trim().toLowerCase();
   // console.log("Filter: " + this.dsLehrlinge.filter);
  }

  /** Announce the change in sort state for assistive technology. */
  announceSortChange(sortState: Sort) {
    if (sortState.direction) {
      this._liveAnnouncer.announce(`Sorted ${sortState.direction}ending`);
    } else {
      this._liveAnnouncer.announce('Sorting cleared');
    }
  }
  onEdit(): void {

  }
  onCancel(): void {
    this.router.navigate(['/list-lehrling']);
  }
}
